@@ -6,14 +6,15 @@ use std::{sync::Arc, task::Poll};
 use anyhow::Context;
 pub use datachannel::{ConnectionState, IceCandidate, RtcConfig, SessionDescription};
 use datachannel::{DataChannelHandler, PeerConnectionHandler, RtcDataChannel, RtcPeerConnection};
+use futures::{
+    channel::mpsc,
+    io::{AsyncRead, AsyncWrite},
+    StreamExt,
+};
 use parking_lot::Mutex;
 #[cfg(feature = "derive")]
 use serde::{Deserialize, Serialize};
-use tokio::{
-    io::{AsyncRead, AsyncWrite},
-    sync::mpsc,
-    task::JoinHandle,
-};
+use tokio::task::JoinHandle;
 use tracing::{debug, error};
 
 #[derive(Debug)]
@@ -53,29 +54,27 @@ impl DataChannelHandler for DataChannel {
     fn on_open(&mut self) {
         debug!("on_open");
         // Signal open
-        let _ = self.tx_ready.blocking_send(Ok(()));
+        let _ = self.tx_ready.try_send(Ok(()));
     }
 
     fn on_closed(&mut self) {
         debug!("on_closed");
-        let _ = self
-            .tx_inbound
-            .blocking_send(Err(anyhow::anyhow!("Closed")));
+        let _ = self.tx_inbound.try_send(Err(anyhow::anyhow!("Closed")));
     }
 
     fn on_error(&mut self, err: &str) {
         let _ = self
             .tx_ready
-            .blocking_send(Err(anyhow::anyhow!(err.to_string())));
+            .try_send(Err(anyhow::anyhow!(err.to_string())));
         let _ = self
             .tx_inbound
-            .blocking_send(Err(anyhow::anyhow!(err.to_string())));
+            .try_send(Err(anyhow::anyhow!(err.to_string())));
     }
 
     fn on_message(&mut self, msg: &[u8]) {
         let s = String::from_utf8_lossy(msg);
         debug!("on_message {}", s);
-        let _ = self.tx_inbound.blocking_send(Ok(msg.to_vec()));
+        let _ = self.tx_inbound.try_send(Ok(msg.to_vec()));
     }
 
     // TODO?
@@ -86,8 +85,7 @@ impl DataChannelHandler for DataChannel {
     }
 }
 
-/// The opened data channel. This struct implements both [`AsyncRead`] and [`AsyncWrite`]
-/// (tokio-flavoured).
+/// The opened data channel. This struct implements both [`AsyncRead`] and [`AsyncWrite`].
 pub struct DataStream {
     /// The actual data channel
     inner: Box<RtcDataChannel<DataChannel>>,
@@ -105,35 +103,38 @@ impl AsyncRead for DataStream {
     fn poll_read(
         mut self: std::pin::Pin<&mut Self>,
         cx: &mut std::task::Context<'_>,
-        buf: &mut tokio::io::ReadBuf<'_>,
-    ) -> std::task::Poll<std::io::Result<()>> {
+        buf: &mut [u8],
+    ) -> std::task::Poll<std::io::Result<usize>> {
         if !self.buf_inbound.is_empty() {
-            let space = buf.remaining();
+            let space = buf.len();
             if self.buf_inbound.len() <= space {
-                buf.put_slice(&self.buf_inbound[..]);
+                let len = self.buf_inbound.len();
+                buf[..len].copy_from_slice(&self.buf_inbound[..]);
                 self.buf_inbound.drain(..);
+                Poll::Ready(Ok(len))
             } else {
-                buf.put_slice(&self.buf_inbound[..space]);
+                buf.copy_from_slice(&self.buf_inbound[..space]);
                 self.buf_inbound.drain(..space);
+                Poll::Ready(Ok(space))
             }
-            Poll::Ready(Ok(()))
         } else {
-            match self.as_mut().rx_inbound.poll_recv(cx) {
+            match self.as_mut().rx_inbound.poll_next_unpin(cx) {
                 std::task::Poll::Ready(Some(Ok(x))) => {
-                    let space = buf.remaining();
+                    let space = buf.len();
                     if x.len() <= space {
-                        buf.put_slice(&x[..]);
+                        buf[..x.len()].copy_from_slice(&x[..]);
+                        Poll::Ready(Ok(x.len()))
                     } else {
-                        buf.put_slice(&x[..space]);
+                        buf.copy_from_slice(&x[..space]);
                         self.buf_inbound.extend_from_slice(&x[space..]);
+                        Poll::Ready(Ok(space))
                     }
-                    Poll::Ready(Ok(()))
                 }
                 std::task::Poll::Ready(Some(Err(e))) => Poll::Ready(Err(std::io::Error::new(
                     std::io::ErrorKind::Other,
                     e.to_string(),
                 ))),
-                std::task::Poll::Ready(None) => Poll::Ready(Ok(())),
+                std::task::Poll::Ready(None) => Poll::Ready(Ok(0)),
                 Poll::Pending => Poll::Pending,
             }
         }
@@ -164,7 +165,7 @@ impl AsyncWrite for DataStream {
         Poll::Ready(Ok(()))
     }
 
-    fn poll_shutdown(
+    fn poll_close(
         self: std::pin::Pin<&mut Self>,
         _cx: &mut std::task::Context<'_>,
     ) -> std::task::Poll<Result<(), std::io::Error>> {
@@ -196,7 +197,7 @@ impl PeerConnection {
         )?));
         let pc = peer_con.clone();
         let handle = tokio::spawn(async move {
-            while let Some(m) = sig_rx.recv().await {
+            while let Some(m) = sig_rx.next().await {
                 if let Err(err) = match m {
                     Message::RemoteDescription(i) => pc.lock().set_remote_description(&i),
                     Message::RemoteCandidate(i) => pc.lock().add_remote_candidate(&i),
@@ -214,7 +215,7 @@ impl PeerConnection {
 
     /// Wait for an inbound connection.
     pub async fn accept(mut self) -> anyhow::Result<DataStream> {
-        let mut s = self.rx_incoming.recv().await.context("Tx dropped")?;
+        let mut s = self.rx_incoming.next().await.context("Tx dropped")?;
         s.handle = Some(self.handle);
         s.peer_con = Some(self.peer_con);
         Ok(s)
@@ -224,7 +225,7 @@ impl PeerConnection {
     pub async fn dial(self, label: &str) -> anyhow::Result<DataStream> {
         let (mut ready, rx_inbound, chan) = DataChannel::new();
         let dc = self.peer_con.lock().create_data_channel(label, chan)?;
-        ready.recv().await.context("Tx dropped")??;
+        ready.next().await.context("Tx dropped")??;
         Ok(DataStream {
             inner: dc,
             rx_inbound,
@@ -253,11 +254,11 @@ impl PeerConnectionHandler for ConnInternal {
     fn on_description(&mut self, sess_desc: SessionDescription) {
         let _ = self
             .tx_signal
-            .blocking_send(Message::RemoteDescription(sess_desc));
+            .try_send(Message::RemoteDescription(sess_desc));
     }
 
     fn on_candidate(&mut self, cand: IceCandidate) {
-        let _ = self.tx_signal.blocking_send(Message::RemoteCandidate(cand));
+        let _ = self.tx_signal.try_send(Message::RemoteCandidate(cand));
     }
 
     fn on_connection_state_change(&mut self, _state: datachannel::ConnectionState) {
@@ -266,7 +267,7 @@ impl PeerConnectionHandler for ConnInternal {
 
     fn on_data_channel(&mut self, data_channel: Box<RtcDataChannel<Self::DCH>>) {
         debug!("new incoming data channel");
-        let _ = self.tx_incoming.blocking_send(DataStream {
+        let _ = self.tx_incoming.try_send(DataStream {
             inner: data_channel,
             rx_inbound: self
                 .pending
